@@ -1,5 +1,6 @@
 /*
- * LALPulsarVCSInfo.h - LALPulsar VCS Information Header
+ * Copyright (C) 2014, 2016 Karl Wette
+ * Copyright (C) 2009-2013 Adam Mercer
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,9 +16,10 @@
  * along with with program; see the file COPYING. If not, write to the
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  * MA 02111-1307 USA
- *
- * Copyright (C) 2009-2013 Adam Mercer
- * Copyright (C) 2014 Karl Wette
+ */
+
+/*
+ * LALPulsarVCSInfo.h - LALPulsar VCS Information Header
  */
 
 /** \cond DONT_DOXYGEN */
@@ -33,37 +35,19 @@
 extern "C" {
 #endif
 
-/* VCS information defines */
-#define LALPULSAR_NAME "LALPulsar"
-#define LALPULSAR_VCS_ID "fac0378b007ef7c15e7ab6c37d688dfe9f07d031"
-#define LALPULSAR_VCS_DATE "2016-10-10 17:31:35 +0000"
+/* VCS information */
+#define LALPULSAR_VCS_ID "b8dafae7797dcf299fd4be7b542546de11810e41"
+#define LALPULSAR_VCS_DATE "2017-02-6 18:16:02 +0000"
 #define LALPULSAR_VCS_BRANCH "None"
-#define LALPULSAR_VCS_TAG "lalpulsar-v1.15.0"
+#define LALPULSAR_VCS_TAG "lalpulsar-v1.16.0"
 #define LALPULSAR_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
 #define LALPULSAR_VCS_COMMITTER "Adam Mercer <adam.mercer@ligo.org>"
+#define LALPULSAR_VCS_CLEAN "CLEAN"
 #define LALPULSAR_VCS_STATUS "CLEAN: All modifications committed"
 
-/* Identable VCS information defines */
-#define LALPULSAR_VCS_IDENT_ID "$" "LALPulsarId: fac0378b007ef7c15e7ab6c37d688dfe9f07d031 " "$"
-#define LALPULSAR_VCS_IDENT_DATE "$" "LALPulsarDate: 2016-10-10 17:31:35 +0000 " "$"
-#define LALPULSAR_VCS_IDENT_BRANCH "$" "LALPulsarBranch: None " "$"
-#define LALPULSAR_VCS_IDENT_TAG "$" "LALPulsarTag: lalpulsar-v1.15.0 " "$"
-#define LALPULSAR_VCS_IDENT_AUTHOR "$" "LALPulsarAuthor: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALPULSAR_VCS_IDENT_COMMITTER "$" "LALPulsarCommitter: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALPULSAR_VCS_IDENT_STATUS "$" "LALPulsarStatus: CLEAN: All modifications committed " "$"
-
-/* Header VCS information structure */
-static const LALVCSInfo lalPulsarVCSInfoHeader = { \
-  LALPULSAR_NAME, \
-  LALPULSAR_VERSION, \
-  LALPULSAR_VCS_ID, \
-  LALPULSAR_VCS_DATE, \
-  LALPULSAR_VCS_BRANCH, \
-  LALPULSAR_VCS_TAG, \
-  LALPULSAR_VCS_AUTHOR, \
-  LALPULSAR_VCS_COMMITTER, \
-  LALPULSAR_VCS_STATUS \
-};
+/* VCS header/library mismatch link check function */
+#define LALPULSAR_VCS_LINK_CHECK LALPULSAR_CLEAN_b8dafae7797dcf299fd4be7b542546de11810e41_VCS_HEADER_LIBRARY_MISMATCH
+void LALPULSAR_VCS_LINK_CHECK(void);
 
 #ifdef __cplusplus
 }
@@ -72,7 +56,3 @@ static const LALVCSInfo lalPulsarVCSInfoHeader = { \
 #endif /* _LALPULSARVCSINFOHEADER_H */
 
 /** \endcond */
-
-/*
- * vim: tw=0 ts=2 et
- */
