@@ -1,5 +1,5 @@
 //
-// Copyright (C) 2007, 2008, 2012, 2014, 2015 Karl Wette
+// Copyright (C) 2007, 2008, 2012, 2014, 2015, 2016 Karl Wette
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -59,10 +59,13 @@ typedef struct tagLatticeTilingLocator LatticeTilingLocator;
 ///
 /// Statistics related to the number/value of lattice tiling points in a dimension.
 ///
+#ifdef SWIG /* SWIG interface directives */
+SWIGLAL(IMMUTABLE_MEMBERS(tagLatticeTilingStats, name));
+#endif /* SWIG */
 typedef struct tagLatticeTilingStats {
+  const char *name;                     ///< Name of parameter-space dimension
   UINT8 total_points;                   ///< Total number of points up to this dimension
   UINT4 min_points;                     ///< Minimum number of points in this dimension
-  double avg_points;                    ///< Average number of points in this dimension
   UINT4 max_points;                     ///< Maximum number of points in this dimension
   double min_value;                     ///< Minimum value of points in this dimension
   double max_value;                     ///< Maximum value of points in this dimension
@@ -107,6 +110,16 @@ int XLALSetLatticeTilingBound(
   const void *data_upper                ///< [in] Arbitrary data describing upper parameter space bound
   );
 
+///
+/// Set the name of a lattice tiling parameter-space dimension.
+///
+int XLALSetLatticeTilingBoundName(
+  LatticeTiling *tiling,                ///< [in] Lattice tiling
+  const size_t dim,                     ///< [in] Dimension to which name applies
+  const char *fmt,                      ///< [in] Name format string
+  ...                                   ///< [in] Arguments to format string
+  ) _LAL_GCC_PRINTF_FORMAT_(3,4);
+
 ///
 /// Set a constant lattice tiling parameter-space bound, given by the minimum and maximum of the two
 /// supplied bounds, on a dimension of the lattice tiling.
@@ -177,7 +190,7 @@ REAL8 XLALLatticeTilingBoundingBox(
 /// Return statistics related to the number/value of lattice tiling points in a dimension.
 ///
 const LatticeTilingStats *XLALLatticeTilingStatistics(
-  LatticeTiling *tiling,                ///< [in] Lattice tiling
+  const LatticeTiling *tiling,          ///< [in] Lattice tiling
   const size_t dim                      ///< [in] Dimension in which to return statistics
   );
 
@@ -269,7 +282,7 @@ int XLALNextLatticeTilingPoints(
 /// Return the total number of points covered by the lattice tiling iterator.
 ///
 UINT8 XLALTotalLatticeTilingPoints(
-  LatticeTilingIterator *itr            ///< [in] Lattice tiling iterator
+  const LatticeTilingIterator *itr      ///< [in] Lattice tiling iterator
   );
 
 ///
